@@ -1,7 +1,7 @@
 // qsynthMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -118,19 +118,24 @@ static inline long lroundf ( float x )
 static qsynthEngine *g_pCurrentEngine = NULL;
 
 
-#ifdef CONFIG_FLUID_SERVER
+#ifdef  CONFIG_FLUID_SERVER
+#ifndef CONFIG_NEW_FLUID_SERVER
 
 // Hold last shell/server port in use.
 static int g_iLastShellPort = 0;
 
-
 // Needed for server mode.
-static fluid_cmd_handler_t* qsynth_newclient ( void* data, char* )
+static fluid_cmd_handler_t *qsynth_newclient ( void *data, char * )
 {
-	return ::new_fluid_cmd_handler((fluid_synth_t*) data);
+	qsynthEngine *pEngine = (qsynthEngine *) data;
+	if (pEngine)
+		return ::new_fluid_cmd_handler(pEngine->pSynth);
+	else
+		return NULL;
 }
 
 #endif
+#endif
 
 
 //-------------------------------------------------------------------------
@@ -1242,7 +1247,7 @@ void qsynthMainForm::systemReset (void)
 
 	qsynthEngine *pEngine = currentEngine();
 	if (pEngine && pEngine->pSynth) {
-	#ifdef CONFIG_FLUID_RESET
+	#ifdef CONFIG_FLUID_SYSTEM_RESET
 		appendMessagesColor(pEngine->name()
 			+ ": fluid_synth_system_reset()", "#993366");
 		::fluid_synth_system_reset(pEngine->pSynth);
@@ -1840,7 +1845,9 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 				"No MIDI input will be available.")
 				.arg(pSetup->sMidiDriver));
 		} else {
+		#ifdef CONFIG_FLUID_MIDI_ROUTER
 			::fluid_synth_set_midi_router(pEngine->pSynth, pEngine->pMidiRouter);
+		#endif
 			appendMessages(sPrefix +
 				tr("Creating MIDI driver (%1)")
 				.arg(pSetup->sMidiDriver) + sElipsis);
@@ -1873,6 +1880,11 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 	if (pSetup->bServer) {
 	#ifdef CONFIG_FLUID_SERVER
 		appendMessages(sPrefix + tr("Creating server") + sElipsis);
+	#ifdef CONFIG_NEW_FLUID_SERVER
+		// Create the server now...
+		pEngine->pServer = ::new_fluid_server(
+			pSetup->fluid_settings(), pEngine->pSynth, pEngine->pMidiRouter);
+	#else
 		// Server port must be different for each engine...
 		char szShellPort[] = "shell.port";
 		if (g_iLastShellPort > 0) {
@@ -1882,8 +1894,14 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 			::fluid_settings_getint(
 				pSetup->fluid_settings(), szShellPort, &g_iLastShellPort);
 			if (g_iLastShellPort == 0) {
+			#ifdef CONFIG_FLUID_SETTINGS_GETINT_DEFAULT
+				g_iLastShellPort = 0;
+				::fluid_settings_getint_default(
+					pSetup->fluid_settings(), szShellPort, &g_iLastShellPort);
+			#else
 				g_iLastShellPort = ::fluid_settings_getint_default(
 					pSetup->fluid_settings(), szShellPort);
+			#endif
 			}
 		}
 		// Set the (new) server port for this engne...
@@ -1891,7 +1909,8 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 			pSetup->fluid_settings(), szShellPort, g_iLastShellPort);
 		// Create the server now...
 		pEngine->pServer = ::new_fluid_server(
-			pSetup->fluid_settings(), qsynth_newclient, pEngine->pSynth);
+			pSetup->fluid_settings(), qsynth_newclient, pEngine);
+	#endif
 		if (pEngine->pServer == NULL)
 			appendMessagesError(sPrefix +
 				tr("Failed to create the server.\n\n"
@@ -2015,15 +2034,23 @@ void qsynthMainForm::stopEngine ( qsynthEngine *pEngine )
 		fluid_sfont_t *pSoundFont
 			= ::fluid_synth_get_sfont(pEngine->pSynth, i);
 		if (pSoundFont) {
+		#ifdef CONFIG_FLUID_SFONT_GET_ID
+			const int iSFID = ::fluid_sfont_get_id(pSoundFont);
+		#else
 			const int iSFID = pSoundFont->id;
-			const QString sName = pSoundFont->get_name(pSoundFont);
+		#endif
+		#ifdef CONFIG_FLUID_SFONT_GET_NAME
+			const QString sSFName = ::fluid_sfont_get_name(pSoundFont);
+		#else
+			const QString sSFName = pSoundFont->get_name(pSoundFont);
+		#endif
 			appendMessagesColor(sPrefix +
 				tr("Unloading soundfont: \"%1\" (SFID=%2)")
-				.arg(sName).arg(iSFID) + sElipsis, "#999933");
+				.arg(sSFName).arg(iSFID) + sElipsis, "#999933");
 			if (::fluid_synth_sfunload(pEngine->pSynth, iSFID, 0) < 0)
 				appendMessagesError(sPrefix +
 					tr("Failed to unload the soundfont: \"%1\".")
-					.arg(sName));
+					.arg(sSFName));
 		}
 	}
 
@@ -2536,8 +2563,16 @@ void qsynthMainForm::refreshChorus (void)
 
 	const int    iChorusNr    = ::fluid_synth_get_chorus_nr(pEngine->pSynth);
 	const double fChorusLevel = ::fluid_synth_get_chorus_level(pEngine->pSynth);
+#ifdef CONFIG_FLUID_SYNTH_GET_CHORUS_SPEED
+	const double fChorusSpeed = ::fluid_synth_get_chorus_speed(pEngine->pSynth);
+#else
 	const double fChorusSpeed = ::fluid_synth_get_chorus_speed_Hz(pEngine->pSynth);
+#endif
+#ifdef CONFIG_FLUID_SYNTH_GET_CHORUS_DEPTH
+	const double fChorusDepth = ::fluid_synth_get_chorus_depth(pEngine->pSynth);
+#else
 	const double fChorusDepth = ::fluid_synth_get_chorus_depth_ms(pEngine->pSynth);
+#endif
 	const int    iChorusType  = ::fluid_synth_get_chorus_type(pEngine->pSynth);
 
 	m_ui.ChorusNrDial->setValue(iChorusNr);
